@@ -4,8 +4,14 @@ package Dancer2::Plugin::Debugger::Panel::Logger;
 
 Dancer2::Plugin::Debugger::Panel::Logger - add logs to debugger panels
 
+=head1 VERSION
+
+0.005
+
 =cut
 
+our $VERSION = '0.005';
+
 use Moo;
 with 'Dancer2::Plugin::Debugger::Role::Panel';
 use namespace::clean;
@@ -19,8 +25,11 @@ sub BUILD {
         Dancer2::Core::Hook->new(
             name => 'engine.logger.after',
             code => sub {
-                my ( $logger, @args ) = @_;
-                push @{ $self->plugin->app->request->env->{$env_key} }, \@args;
+                if ( $self->plugin->app->request ) {
+                    my ( $logger, @args ) = @_;
+                    push @{ $self->plugin->app->request->env->{$env_key} },
+                      \@args;
+                }
             },
         )
     );
