@@ -4,8 +4,14 @@ package Dancer2::Plugin::Debugger::Panel::Session;
 
 Dancer2::Plugin::Debugger::Panel::Session - add session data to debugger panels
 
+=head1 VERSION
+
+0.005
+
 =cut
 
+our $VERSION = '0.005';
+
 use Moo;
 with 'Dancer2::Plugin::Debugger::Role::Panel';
 use namespace::clean;
@@ -19,8 +25,12 @@ sub BUILD {
         Dancer2::Core::Hook->new(
             name => 'after_layout_render',
             code => sub {
-                my $session = $self->plugin->app->session->data;
-                $self->plugin->app->request->env->{$env_key} = $session;
+                if (   $self->plugin->app->request
+                    && $self->plugin->app->session )
+                {
+                    my $session = $self->plugin->app->session->data;
+                    $self->plugin->app->request->env->{$env_key} = $session;
+                }
             },
         )
     );
