@@ -4,8 +4,14 @@ package Dancer2::Plugin::Debugger::Panel::Settings;
 
 Dancer2::Plugin::Debugger::Panel::Settings - add settings data to debugger panels
 
+=head1 VERSION
+
+0.005
+
 =cut
 
+our $VERSION = '0.005';
+
 use Moo;
 with 'Dancer2::Plugin::Debugger::Role::Panel';
 use namespace::clean;
@@ -19,9 +25,12 @@ sub BUILD {
         Dancer2::Core::Hook->new(
             name => 'before',
             code => sub {
-                my $settings = $self->plugin->app->config;
-                # make a copy
-                $self->plugin->app->request->env->{$env_key} = { %$settings };
+                if ( $self->plugin->app->request ) {
+                    my $settings = $self->plugin->app->config;
+
+                    # make a copy
+                    $self->plugin->app->request->env->{$env_key} = {%$settings};
+                }
             },
         )
     );
