@@ -4,8 +4,14 @@ package Dancer2::Plugin::Debugger::Panel::TemplateVariables;
 
 Dancer2::Plugin::Debugger::Panel::TemplateVariables - add template tokens to debugger panels
 
+=head1 VERSION
+
+0.005
+
 =cut
 
+our $VERSION = '0.005';
+
 use Moo;
 with 'Dancer2::Plugin::Debugger::Role::Panel';
 use namespace::clean;
@@ -19,8 +25,10 @@ sub BUILD {
         Dancer2::Core::Hook->new(
             name => 'before_layout_render',
             code => sub {
-                my $tokens = shift;
-                $self->plugin->app->request->env->{$env_key} = $tokens;
+                if ( $self->plugin->app->request ) {
+                    my $tokens = shift;
+                    $self->plugin->app->request->env->{$env_key} = $tokens;
+                }
             },
         )
     );
